@@ -175,7 +175,7 @@ g_socket_control_message_deserialize (int      level,
   GSocketControlMessage *message;
   GType *message_types;
   guint n_message_types;
-  int i;
+  guint i;
 
   /* Ensure we know about the built in types */
 #ifndef G_OS_WIN32
